@@ -57,6 +57,7 @@ from pennylane.operation import (
 from braket.pennylane_plugin.translation import (
     supported_operations,
     translate_operation,
+    translate_result,
     translate_result_type,
 )
 
@@ -85,7 +86,7 @@ class BraketQubitDevice(QubitDevice):
         **run_kwargs: Variable length keyword arguments for ``braket.devices.Device.run()`.
     """
     name = "Braket PennyLane plugin"
-    pennylane_requires = ">=0.16.0"
+    pennylane_requires = ">=0.18.0"
     version = __version__
     author = "Amazon Web Services"
 
@@ -122,6 +123,13 @@ class BraketQubitDevice(QubitDevice):
         """FrozenSet[str]: The set of names of PennyLane operations that the device supports."""
         return self._supported_ops
 
+    @property
+    def observables(self) -> FrozenSet[str]:
+        base_observables = frozenset(super().observables)
+        if not self.shots:
+            return base_observables.union({"Hamiltonian"})
+        return base_observables
+
     @property
     def circuit(self) -> Circuit:
         """Circuit: The last circuit run on this device."""
@@ -141,9 +149,12 @@ class BraketQubitDevice(QubitDevice):
         )
         for observable in circuit.observables:
             dev_wires = self.map_wires(observable.wires).tolist()
-            braket_circuit.add_result_type(
-                translate_result_type(observable, dev_wires, self._braket_result_types)
-            )
+            translated = translate_result_type(observable, dev_wires, self._braket_result_types)
+            if isinstance(translated, tuple):
+                for result_type in translated:
+                    braket_circuit.add_result_type(result_type)
+            else:
+                braket_circuit.add_result_type(translated)
         return braket_circuit
 
     def statistics(
@@ -189,6 +200,11 @@ class BraketQubitDevice(QubitDevice):
         self.check_validity(circuit.operations, circuit.observables)
         self._circuit = self._pl_to_braket_circuit(circuit, **run_kwargs)
         self._task = self._run_task(self._circuit)
+
+        if self.tracker.active:
+            self.tracker.update(executions=1, shots=self.shots)
+            self.tracker.record()
+
         return self._braket_to_pl_result(self._task.result(), circuit)
 
     def apply(
@@ -227,9 +243,7 @@ class BraketQubitDevice(QubitDevice):
 
     def _get_statistic(self, braket_result, observable):
         dev_wires = self.map_wires(observable.wires).tolist()
-        return braket_result.get_value_by_result_type(
-            translate_result_type(observable, dev_wires, self._braket_result_types)
-        )
+        return translate_result(braket_result, observable, dev_wires, self._braket_result_types)
 
 
 class BraketAwsQubitDevice(BraketQubitDevice):
@@ -331,10 +345,12 @@ class BraketAwsQubitDevice(BraketQubitDevice):
             self._pl_to_braket_circuit(circuit, **run_kwargs) for circuit in circuits
         ]
 
+        batch_shots = 0 if self.analytic else self.shots
+
         task_batch = self._device.run_batch(
             braket_circuits,
             s3_destination_folder=self._s3_folder,
-            shots=0 if self.analytic else self.shots,
+            shots=batch_shots,
             max_parallel=self._max_parallel,
             max_connections=self._max_connections,
             poll_timeout_seconds=self._poll_timeout_seconds,
@@ -345,6 +361,13 @@ class BraketAwsQubitDevice(BraketQubitDevice):
         braket_results_batch = task_batch.results(
             fail_unsuccessful=True, max_retries=self._max_retries
         )
+
+        if self.tracker.active:
+            batch_len = len(circuits)
+            total_shots = batch_len * batch_shots
+            self.tracker.update(batches=1, executions=batch_len, shots=total_shots)
+            self.tracker.record()
+
         return [
             self._braket_to_pl_result(braket_result, circuit)
             for braket_result, circuit in zip(braket_results_batch, circuits)
